/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.ee.component;

/**
 * A description of an {@link javax.interceptor.Interceptor @Interceptor} annotation value or its equivalent
 * deployment descriptor construct.
 *
 * @author <a href="mailto:david.lloyd@redhat.com">David M. Lloyd</a>
 */
public final class InterceptorDescription {
    private final String interceptorClassName;

    public InterceptorDescription(final String interceptorClassName) {
        this.interceptorClassName = interceptorClassName;
    }

    public String getInterceptorClassName() {
        return interceptorClassName;
    }

    @Override
    public boolean equals(final Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        final InterceptorDescription that = (InterceptorDescription) o;

        if (interceptorClassName != null ? !interceptorClassName.equals(that.interceptorClassName) : that.interceptorClassName != null)
            return false;

        return true;
    }

    @Override
    public int hashCode() {
        return interceptorClassName != null ? interceptorClassName.hashCode() : 0;
    }
}
